<?php

if(!is_object($plugins)) $plugins = &$GLOBALS['plugins'];

$plugins->add_hook("admin_badwords_do_add", "preparse_clear_cache");
$plugins->add_hook("admin_badwords_do_edit", "preparse_clear_cache");
$plugins->add_hook("admin_badwords_delete", "preparse_clear_cache");
$plugins->add_hook("admin_mycode_do_add", "preparse_clear_cache");
$plugins->add_hook("admin_mycode_do_edit", "preparse_clear_cache");
$plugins->add_hook("admin_mycode_do_delete", "preparse_clear_cache");
$plugins->add_hook("admin_smilies_do_add", "preparse_clear_cache");
$plugins->add_hook("admin_smilies_do_delete", "preparse_clear_cache");
$plugins->add_hook("admin_smilies_do_edit", "preparse_clear_cache");
$plugins->add_hook("admin_smilies_do_addmultiple", "preparse_clear_cache");

function preparser_info()
{
	return array(
		"name"			=> "PreParse Cache",
		"description"	=> "A plugin which aims to speed up MyBB's showthread by caching parsed versions of posts and signatures and hard filtering thread/post subjects.",
		"website"		=> "http://endlessparadigm.com",
		"author"		=> "ZiNgA BuRgA",
		"authorsite"	=> "http://zingaburga.com",
		"version"		=> "1.0 beta",
	);
}

function preparser_activate()
{
	global $db;
	$db->query('CREATE TABLE IF NOT EXISTS '.TABLE_PREFIX.'parsed_sigs (
		uid int NOT NULL,
		parsedsig text NOT NULL,
		lastparse bigint(30) NOT NULL default \'0\',
		PRIMARY KEY (uid), KEY (lastparse)
	);');
	$db->query('CREATE TABLE IF NOT EXISTS '.TABLE_PREFIX.'parsed_posts (
		pid int NOT NULL,
		parsedmessage text NOT NULL,
		lastparse bigint(30) NOT NULL default \'0\',
		PRIMARY KEY (pid), KEY (lastparse)
	);');
	
	
	$db->insert_query(TABLE_PREFIX."settinggroups", array(
		'name' => 'preparser', 
		'title' => 'PreParse Cache Settings', 
		'description' => '', 
		'disporder' => 100, 
		'isdefault' => 'no'
	));
	$settings_gid = $db->insert_id();
	
	$db->insert_query(TABLE_PREFIX.'settings', array(
		'gid' => $settings_gid,
		'name' => 'preparse_time',
		'title' => 'Keep Parsed Posts &amp; Signatures for (days)',
		'description' => 'How long preparsed posts and signatures are stored in the database',
		'optionscode' => 'text',
		'value' => 7,
		'disporder' => 1
	));
}

function preparser_deactivate()
{
	global $db;
	$db->query("DROP TABLE IF EXISTS `".TABLE_PREFIX."parsed_sigs`, `".TABLE_PREFIX."parsed_posts`");
	$settings_gid = $db->fetch_field($db->simple_select(TABLE_PREFIX.'settinggroups', 'gid', "name='preparser'"), 'gid');
	$db->delete_query(TABLE_PREFIX.'settings', "gid=$settings_gid");
	$db->delete_query(TABLE_PREFIX.'settinggroups', "gid=$settings_gid");
}


function preparse_clear_cache()
{
	global $db;
	$db->query('TRUNCATE TABLE '.TABLE_PREFIX.'parsed_posts');
	$db->query('TRUNCATE TABLE '.TABLE_PREFIX.'parsed_sigs');
}



function preparse_post_new($posthandler)
{
	global $db, $parser;
	if(!isset($parser))
	{
		require_once MYBB_ROOT.'inc/class_parser.php';
		$parser = new postParser;
	}
	
	$pdata = &$posthandler->data;
	if(isset($posthandler->post_update_data))
	{
		$posthandler->post_update_data['subject'] = $db->escape_string($parser->parse_badwords($pdata['subject']));
	}
	if(isset($posthandler->post_insert_data))
	{
		$posthandler->post_insert_data['subject'] = $db->escape_string($parser->parse_badwords($pdata['subject']));
	}
	
	if($pdata['pid']) // posting draft?
		$pid = $pdata['pid'];
	else
		$pid = db_get_next_auto_increment(TABLE_PREFIX.'posts');
	update_parsed_post($pid, $pdata, true);
}

function preparse_post_update($posthandler)
{
	global $db, $parser, $parsed_data;
	if(!isset($parser))
	{
		require_once MYBB_ROOT.'inc/class_parser.php';
		$parser = new postParser;
	}
	
	$pdata = &$posthandler->data;
	if(isset($posthandler->post_update_data['message']))
	{
		$parsed_data = update_parsed_post($pdata['pid'], $pdata);
	}
	if(isset($posthandler->post_update_data['subject']))
		$posthandler->post_update_data['subject'] = $db->escape_string($parser->parse_badwords($pdata['subject']));
}

function preparse_post_merge($info)
{
	global $db;
	// can't do much, so we'll just clear the cache
	$db->delete_query(TABLE_PREFIX.'parsed_posts', 'pid IN ('.implode(',',$info['pids']).')');
}

function preparse_post_delete($pid)
{
	global $db;
	$db->delete_query(TABLE_PREFIX.'parsed_posts', 'pid = '.$pid);
}

// can't be stuffed doing delete thread - meh, preparsed posts will expire anyway






function thread_hardfilter($posthandler)
{
	global $parser, $db;
	if(!isset($parser))
	{
		require_once MYBB_ROOT.'inc/class_parser.php';
		$parser = new postParser;
	}
	
	$posthandler->thread_insert_data['subject'] = $db->escape_string($parser->parse_badwords($posthandler->data['subject']));
}

function thread_update_hardfilter($posthandler)
{
	global $parser, $db;
	if(!isset($parser))
	{
		require_once MYBB_ROOT.'inc/class_parser.php';
		$parser = new postParser;
	}
	
	if(isset($posthandler->thread_update_data['subject']))
		$posthandler->thread_update_data['subject'] = $db->escape_string($parser->parse_badwords($posthandler->data['subject']));
}

function user_parse($userhandler)
{
	update_parsed_sig($userhandler->data);
}

function sig_update()
{
	global $mybb;
	$user = $mybb->user;
	$user['signature'] = $mybb->input['signature'];
	update_parsed_sig($user);
}

function db_get_next_auto_increment($table)
{
	global $db;
	$status = $db->fetch_array($db->query("SHOW TABLE STATUS LIKE '$table'"));
	
	return $status['Auto_increment'];
}


function preparse_include_parser()
{
	global $parser;
	if(!isset($parser))
	{
		require_once MYBB_ROOT.'inc/class_parser.php';
		$parser = new postParser;
	}
}


?>